@@ -17,11 +17,11 @@ ZConf - A configuration system allowing for either file or LDAP backed storage.
 
 =head1 VERSION
 
-Version 0.2.0
+Version 0.3.1
 
 =cut
 
-our $VERSION = '0.2.0';
+our $VERSION = '0.3.0';
 
 =head1 SYNOPSIS
 
@@ -46,10 +46,14 @@ is returned. The hash can contain various initization options.
 
 When it is run for the first time, it creates a filesystem only config file.
 
+=over
+
 =item file
 
 The default is 'xdf_config_home/zconf.zml', which is generally '~/.config/zconf.zml'.
 
+=back
+
 =cut
 
 #create it...
@@ -873,9 +877,46 @@ sub createConfigLDAP{
 	return 1;
 };
 
+=head2 defaultSetExists
+
+This checks to if the default set for a config exists. It takes one arguement,
+which is the name of the config. The returned value is a Perl boolean.
+
+=cut
+
+sub defaultSetExists{
+	my $self=$_[0];
+	my $config=$_[1];
+
+	$self->errorBlank();
+
+	#make sure the config name is legit
+	my ($error, $errorString)=$self->configNameCheck($config);
+	if(defined($error)){
+		warn("ZConf defaultSetExists:".$error.": ".$errorString);
+		$self->{error}=$error;
+		$self->{errorString}=$errorString;
+		return undef;
+	};
+
+	#makes sure it exists
+	if (!$self->configExists($config)){
+		warn('ZConf defaultSetExists:12: The specified config, "'.$config.'" does not exist');
+		return undef;
+	}
+
+	#figures out what to use for the set
+	my $set=$self->chooseSet($config);
+	if (defined($self->{error})){
+		return undef;
+	}
+
+	return 1;
+}
+
 =head2 errorBlank
 
-This blanks the error storage and is only meant to not meant to be called.
+This blanks the error storage and is only meant for internal usage.
 
 It does the following.
 
@@ -900,7 +941,7 @@ This gets the available sets for a config.
 
 The only arguement is the name of the configuration in question.
 
-	my @sets = $zconf->getAvailableSets("foo/bar")
+	my @sets = $zconf->getAvailableSets("foo/bar");
 	if($zconf->{error}){
 		print 'error: '.$zconf->{error}."\n".$zconf->errorString."\n";
 	};
@@ -949,7 +990,7 @@ sub getAvailableSets{
 This is exactly the same as getAvailableSets, but for the file back end.
 For the most part it is not intended to be called directly.
 
-	my @sets = $zconf->getAvailableSetsFile("foo/bar")
+	my @sets = $zconf->getAvailableSetsFile("foo/bar");
 	if($zconf->{error}){
 		print 'error: '.$zconf->{error}."\n".$zconf->errorString."\n";
 	};
@@ -1001,7 +1042,7 @@ sub getAvailableSetsFile{
 This is exactly the same as getAvailableSets, but for the file back end.
 For the most part it is not intended to be called directly.
 
-	my @sets = $zconf->getAvailableSetsLDAP("foo/bar")
+	my @sets = $zconf->getAvailableSetsLDAP("foo/bar");
 	if($zconf->{error}){
 		print 'error: '.$zconf->{error}."\n".$zconf->errorString."\n";
 	};
@@ -1408,7 +1449,7 @@ sub read{
 			print "zconf read error: Could not sync config to the loaded config.";
 		};
 	};
-		
+
 	return 1;
 };
 
@@ -1471,7 +1512,7 @@ sub readFile{
 	close("thefile");
 
 	#at this point we add
-	$self->{config}{$args{config}}={};
+	$self->{conf}{$args{config}}={};
 
 	my $rawdataInt=0;
 	my $prevVar=undef;
@@ -1482,14 +1523,14 @@ sub readFile{
 				chomp($rawdata[$rawdataInt]);
 				$rawdata[$rawdataInt]=~s/^ //;#remove the trailing space
 				#add in the line return and 
-				$self->{config}{$args{config}}{$prevVar}=
-					$self->{config}{$args{config}}{$prevVar}."\n".$rawdata[$rawdataInt];
+				$self->{conf}{$args{config}}{$prevVar}=
+					$self->{conf}{$args{config}}{$prevVar}."\n".$rawdata[$rawdataInt];
 			};
 		}else{
 			#split it into two
 			my @linesplit=split(/=/, $rawdata[$rawdataInt], 2);
 			chomp($linesplit[1]);
-			$self->{config}{$args{config}}{$linesplit[0]}=$linesplit[1];
+			$self->{conf}{$args{config}}{$linesplit[0]}=$linesplit[1];
 			$prevVar=$linesplit[0];#this is used if the next line is a continuation from the previous
 		};
 
@@ -2115,6 +2156,44 @@ sub setVar{
 	return 1;
 };
 
+=head2 unloadConfig
+
+Unloads a specified configuration. The only required value is the
+set name. The return value is a Perl boolean value.
+
+    if(!$zconf->unloadConfig($config)){
+        print "error: ".$zconf->{error}."\n";
+    }
+
+=cut
+
+sub unloadConfig{
+	my $self=$_[0];
+	my $config=$_[1];
+
+	$self->errorBlank();
+
+	if (!defined($self->{conf}{$config})){
+		warn('ZConf:26: The specified config, ".$config.", is not loaded');
+		$self->{error}=26;
+		$self->{errorString}='The specified config, ".$config.", is not loaded';
+		#even if it is not defined, check to see if this is defined and remove it
+		if (defined($self->{set}{$config})){
+			undef($self->{set}{$config});
+		}
+		return undef;
+	}else {
+		undef($self->{conf}{$config});
+	}
+
+	#removes the loaded set information
+	if (defined($self->{set}{$config})){
+		undef($self->{set}{$config});
+	}
+
+	return 1;
+}
+
 =head2 varNameCheck
 
 	my ($error, $errorString) = $zconf->varNameCheck($config);
@@ -2133,7 +2212,7 @@ sub varNameCheck{
         if($name =~ /,/){
                 return("0", "variavble name,'".$name."', contains ','");
         };
-                
+
         #checks for /.
         if($name =~ /\/\./){
                 return("1", "variavble name,'".$name."', contains '/.'");
@@ -2635,7 +2714,7 @@ writeSetFromHash, but functions just on the LDAP backend.
 	if($zconf->{error}){
 		print 'error: '.$zconf->{error}."\n".$zconf->errorString."\n";
 	};
-	
+
 =cut
 
 #write out a config from a hash to the LDAP backend
@@ -3337,7 +3416,6 @@ This is the password to use for when connecting to the server.
 	#    .1 zconfChooser
 	#    .2 zconfSet
 	
-	#zmsServerPassword
 	attributeType ( 1.3.6.1.4.1.26481.2.7.0
 		NAME 'zconfData'
 		DESC 'Data attribute for a zconf entry.'
@@ -3359,7 +3437,6 @@ This is the password to use for when connecting to the server.
 		EQUALITY caseExactMatch
 		)
 
-	#zmsServerProfile
 	objectclass ( 1.3.6.1.4.1.26481.2.7
 		NAME 'zconf'
 		DESC 'A zconf entry.'
